==> sghi_core-0.2.30.tar.gz: lib/communities/core/utils.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart';
import 'package:image_picker/image_picker.dart';
import 'package:sghi_core/communities/core/endpoints.dart';
import 'package:sghi_core/flutter_graphql_client/constants.dart';
import 'package:sghi_core/flutter_graphql_client/i_flutter_graphql_client.dart';

Future<Map<String, dynamic>> fetchRoomPowerLevels(
  String roomID,
  IGraphQlClient client,
) async {
  final Response response = await client.callRESTAPI(
    endpoint: roomPowerLevelsEndpoint(roomID),
    method: kGetMethodName,
    variables: <String, dynamic>{},
  );

  final dynamic data = await json.decode(utf8.decode(response.bodyBytes));

  return data as Map<String, dynamic>;
}

///
/// Overrides mime types
///
/// Formatting mimeTypes through lookup
/// didn't work for heic
///
String convertMimeTypes(
  File file,
  String? mimeType,
) {
  if (file.path.toLowerCase().contains('heic')) {
    return 'image/heic';
  }

  if (mimeType == null) {
    throw 'Unsupported Media type for a message';
  }

  return mimeType;
}

Future<File?> selectPhoto({required ImagePicker picker}) async {
  // Has a problem with image path
  // final XFile? imgXFile = await picker.pickImage(
  //   source: ImageSource.gallery, // We will do gallery for now
  // );

  // ignore: deprecated_member_use
  final PickedFile? image = await picker.getImage(source: ImageSource.gallery);

  if (image == null) return null;

  final File file = File(image.path);

  /// Consider compressing the image
  return file;
}

==> sghi_core-0.2.36.tar.gz: lib/communities/core/utils.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart';
import 'package:image_picker/image_picker.dart';
import 'package:sghi_core/communities/core/endpoints.dart';
import 'package:sghi_core/communities/models/room_power_level.dart';
import 'package:sghi_core/flutter_graphql_client/constants.dart';
import 'package:sghi_core/flutter_graphql_client/i_flutter_graphql_client.dart';

Future<RoomPowerLevel> fetchRoomPowerLevels(
  String roomID,
  IGraphQlClient client,
) async {
  final Response response = await client.callRESTAPI(
    endpoint: roomPowerLevelsEndpoint(roomID),
    method: kGetMethodName,
    variables: <String, dynamic>{},
  );

  final dynamic data = await json.decode(utf8.decode(response.bodyBytes));

  final RoomPowerLevel powerLevel =
      RoomPowerLevel.fromJson(data as Map<String, dynamic>);

  return powerLevel;
}

///
/// Overrides mime types
///
/// Formatting mimeTypes through lookup
/// didn't work for heic
///
String convertMimeTypes(
  File file,
  String? mimeType,
) {
  if (file.path.toLowerCase().contains('heic')) {
    return 'image/heic';
  }

  if (mimeType == null) {
    throw 'Unsupported Media type for a message';
  }

  return mimeType;
}

Future<File?> selectPhoto({required ImagePicker picker}) async {
  // Has a problem with image path
  // final XFile? imgXFile = await picker.pickImage(
  //   source: ImageSource.gallery, // We will do gallery for now
  // );

  // ignore: deprecated_member_use
  final PickedFile? image = await picker.getImage(source: ImageSource.gallery);

  if (image == null) return null;

  final File file = File(image.path);

  /// Consider compressing the image
  return file;
}
